tests.models package — django_analyses 0.0.3 documentation

# tests.models package

## Subpackages

- tests.models.input package
  - Subpackages
    - tests.models.input.definitions package
      - Submodules
      - tests.models.input.definitions.test_boolean_input_definition module
      - tests.models.input.definitions.test_file_input_definition module
      - tests.models.input.definitions.test_float_input_definition module
      - tests.models.input.definitions.test_input_definition module
      - tests.models.input.definitions.test_integer_input_definition module
      - tests.models.input.definitions.test_list_input_definition module
      - tests.models.input.definitions.test_string_input_definition module
      - Module contents
    - tests.models.input.types package
      - Submodules
      - tests.models.input.types.test_boolean_input module
      - tests.models.input.types.test_file_input module
      - tests.models.input.types.test_float_input module
      - tests.models.input.types.test_integer_input module
      - tests.models.input.types.test_list_input module
      - tests.models.input.types.test_string_input module
      - Module contents
  - Submodules
  - tests.models.input.test_input_specification module
  - Module contents
- tests.models.managers package
  - Submodules
  - tests.models.managers.fixtures module
  - tests.models.managers.test_analysis_manager module
  - tests.models.managers.test_run_manager module
  - Module contents
- tests.models.output package
  - Subpackages
    - tests.models.output.definitions package
      - Submodules
      - tests.models.output.definitions.test_file_output_definition module
      - tests.models.output.definitions.test_float_output_definition module
      - tests.models.output.definitions.test_output_definition module
      - Module contents
    - tests.models.output.types package
      - Submodules
      - tests.models.output.types.test_file_output module
      - tests.models.output.types.test_float_output module
      - Module contents
  - Submodules
  - tests.models.output.test_output_specification module
  - Module contents
- tests.models.pipeline package
  - Submodules
  - tests.models.pipeline.test_node module
  - tests.models.pipeline.test_pipe module
  - tests.models.pipeline.test_pipeline module
  - Module contents

## Submodules

## tests.models.test_analysis module

class `tests.models.test_analysis.` `AnalysisTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `Analysis` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_category_is_nullable`()

    Tests that the category field is nullable.

  `test_description_blank_and_null`()

    Tests that the description field may be blank or null.

  `test_description_is_not_unique`()

    Tests that the description field is not set to unique.

  `test_ordering`()

    Test the ordering of the `Analysis` model.

  `test_string`()

    Test the string output of the `Analysis` model.

  `test_title_blank_and_null`()

    Tests that the title field may not be blank or null.

  `test_title_is_unique`()

    Tests that the title field is unique.

  `test_title_max_length`()

    Test the max_length of the title field.

  `test_verbose_name_plural`()

    Test the verbose name plural of the `Analysis` model.

## tests.models.test_analysis_version module

class `tests.models.test_analysis_version.` `AnalysisVersionTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `AnalysisVersion` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_extract_results_with_nested_attribute`()
  `test_extract_results_without_nested_attribute`()
  `test_get_interface_with_interface`()
  `test_get_interface_without_interface_raises_exception`()
  `test_input_definitions`()
  `test_nested_results_parts`()
  `test_ordering`()

    Validate the ordering of the model.

  `test_output_definitions`()
  `test_run_inteface`()
  `test_run_inteface_with_custom_run_method_key`()
  `test_run_with_default_value`()
  `test_run_with_invalid_kwarg_keys`()
  `test_run_with_missing_required`()
  `test_run_with_valid_arguments`()
  `test_string`()

    Test the string method of the model.

  `test_update_input_with_defaults`()

## tests.models.test_category module

class `tests.models.test_category.` `CategoryTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `Category` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_creation_with_parent_category`()

    Tests creating a category with an existing category as the parent.

  `test_description_blank_and_null`()

    Validates that the description field may be blank or null.

  `test_description_is_not_unique`()

    Validates that the description field is not set to unique.

  `test_ordering`()

    Validate the ordering of the `Category` model.

  `test_parent_is_nullable`()

    Validates that the parent field is nullable.

  `test_settings_a_parent_category`()

    Tests setting a parent category.

  `test_string`()

    Validate the string output of the `category` model.

  `test_title_blank_and_null`()

    Validates that the title field may not be blank or null.

  `test_title_is_unique`()

    Validates that the title field is unique.

  `test_title_max_length`()

    Validate the max_length of the title field.

  `test_verbose_name_plural`()

    Validate the verbose name plural of the `Category` model.

## tests.models.test_run module

class `tests.models.test_run.` `RunTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `Run` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_input_configuration`()
  `test_input_defaults`()
  `test_input_set`()
  `test_output_configuration`()
  `test_output_set`()
  `test_raw_input_configuration`()
  `test_string`()

## Module contents